import { RecordingEvent, WorkerRequest, WorkerResponse } from './types';
interface CreateEventBufferParams {
    useCompression: boolean;
}
export declare function createEventBuffer({ useCompression }: CreateEventBufferParams): EventBufferCompressionWorker | EventBufferArray;
export interface IEventBuffer {
    get length(): number;
    destroy(): void;
    addEvent(event: RecordingEvent, isCheckout?: boolean): void;
    finish(): Promise<string | Uint8Array>;
}
declare class EventBufferArray implements IEventBuffer {
    events: RecordingEvent[];
    constructor();
    destroy(): void;
    get length(): number;
    addEvent(event: RecordingEvent, isCheckout?: boolean): void;
    finish(): Promise<string>;
}
export declare class EventBufferCompressionWorker implements IEventBuffer {
    private worker;
    private eventBufferItemLength;
    private _id;
    constructor(worker: Worker);
    /**
     * Read-only incrementing counter
     */
    get id(): number;
    /**
     * Post message to worker and wait for response before resolving promise.
     */
    postMessage({ id, method, args, }: WorkerRequest): Promise<WorkerResponse['response']>;
    init(): void;
    destroy(): void;
    /**
     * Note that this may not reflect what is actually in the event buffer. This
     * is only a local count of the buffer size since `addEvent` is async.
     */
    get length(): number;
    addEvent(event: RecordingEvent, isCheckout?: boolean): Promise<string | Uint8Array>;
    sendEventToWorker: (event: RecordingEvent) => Promise<string | Uint8Array>;
    finishRequest: (id: number) => Promise<Uint8Array>;
    finish(): Promise<Uint8Array>;
}
export {};
